@@ -1,5 +1,5 @@
-mod service;
-mod factories;
+pub mod service;
+pub mod factories;
 mod providers;
 mod props;
 mod factories_tests;
